var product_countdown;

(function () {
	"use strict";

	product_countdown = function () {

		this.init = function () {

			/* Init select2 on settings page */
			jQuery( '#homepage_product' ).addClass( 'wpbpc-select2-search' );

			this.on_off_select          = jQuery( '#_wpbpc_countdown' );
			this.form_fields            = jQuery( '.wpbpc-form-fields' );
			this.action_select          = jQuery( '#_wpbpc_action' );
			this.product_type           = jQuery( '#product-type' );
			this.color_pickers          = jQuery( '#_wpbpc_background_color, #_wpbpc_font_color' );
			this.select2_search_field   = jQuery( '.wpbpc-select2-search' );
			this.product_id_field       = null;
			this.select2                = null;
			this.select2_search_results = null;
			this.select2_close_btn      = null;

			var self = this;

			/* Init Color Pickers */
			if ( jQuery.isFunction( jQuery.fn.wpColorPicker ) ) {
				this.color_pickers.wpColorPicker();
			}

			this.select2_init();

			/* Toggles */
			this.toggle_options();
			this.action_display();
			this.variable_product_action_hint();

			/* Events */
			this.on_off_select.on( 'change', function () {
				self.toggle_options();
			} );

			this.action_select.on( 'change', function () {
				self.action_display();
			} );

			this.product_type.on( 'change', function () {
				self.variable_product_action_hint();
			} );
		};

		this.toggle_options = function () {
			if ( 1 === parseInt( this.on_off_select.val() ) ) {
				this.form_fields.css( 'display', 'block' );
			} else {
				this.form_fields.css( 'display', 'none' );
			}
		};

		this.action_display = function () {
			var action = jQuery( '#_wpbpc_action' ).val();

			switch ( action ) {
				case 'email':
					jQuery( '#_wpbpc_redirect_url, #_wpbpc_end_message' ).parent().hide();
					jQuery( '#_wpbpc_email, #_wpbpc_email_message' ).parent().show();
					break;
				case 'redirect':
					jQuery( '#_wpbpc_redirect_url' ).parent().show();
					jQuery( '#_wpbpc_email, #_wpbpc_email_message, #_wpbpc_end_message' ).parent().hide();
					break;
				case 'message':
					jQuery( '#_wpbpc_end_message' ).parent().show();
					jQuery( '#_wpbpc_email, #_wpbpc_email_message, #_wpbpc_redirect_url' ).parent().hide();
					break;
				default:
					jQuery( '#_wpbpc_email, #_wpbpc_email_message, #_wpbpc_end_message, #_wpbpc_redirect_url' ).parent().hide();
			}
		};

		this.variable_product_action_hint = function () {
			if ( jQuery( '#product-type' ).val() !== 'variable' ) {
				jQuery( '#_wpbpc_action' ).parent().find( 'span.description' ).css( 'color', '' );
			} else {
				jQuery( '#_wpbpc_action' ).parent().find( 'span.description' ).css( 'color', 'red' );
			}
		};

		this.select2_close = function () {
			this.select2_search_results.css( 'display', 'none' );
		};

		this.select2_open = function () {
			this.select2_search_results.css( 'display', 'block' );
		};

		this.select2_search = function () {
			var self = this;

			/* Do not trigger when string length is < 3 */
			var q = this.select2_search_field.val();
			if ( q.length < 3 ) {
				return true;
			}

			this.select2_open();
			this.select2_search_results.find( 'ul' ).html( '<li>' + WPBPC.loading + '</li>' );

			wp.api.init( { 'versionString': 'wc/v2/' } );

			var products = new wp.api.models.Products();

			products.fetch( { 'search': q } ).done( function ( data ) {
				var ul = self.select2_search_results.find( 'ul' );
				ul.html( '' );

				jQuery.each( data, function ( index, product ) {
					ul.append( '<li data-id="' + product.id + '" data-title="' + product.name + '">' + product.name + ' (ID: ' + product.id + ')</li>' )
				} );
			} );
		};

		this.select2_select = function ( $clicked_obj ) {
			var product_id    = $clicked_obj.data( 'id' );
			var product_title = $clicked_obj.data( 'title' );

			this.product_id_field.val( product_id );
			this.select2_search_field.val( product_title + ' (ID: ' + product_id + ')' );

			this.select2_close();

		};

		this.select2_get_product = function ( product_id ) {
			var self = this;

			wp.api.init( { 'versionString': 'wc/v2/' } );

			var products = new wp.api.models.Product( { 'id': product_id } );

			products.fetch()
				.done( function ( data ) {
					self.select2_search_field.val( data.title.rendered + ' (ID: ' + product_id + ')' );
				} )
				.fail( function () {
					self.select2_search_field.val( WPBPC.could_not_load_product_title );
				} );
		};

		this.select2_init = function () {
			var self = this;

			var name       = this.select2_search_field.prop( 'name' );
			var product_id = parseInt( this.select2_search_field.val() );

			this.select2_search_field.val( '' );
			this.select2_search_field.prop( 'name', '' );
			this.select2_search_field.prop( 'type', 'search' );
			this.select2_search_field.prop( 'placeholder', WPBPC.start_typing_to_search_for_a_product );

			this.select2_search_field.wrap( '<div class="wpbpc-select2"></div>' );
			this.select2_search_field.after( '<input type="hidden" name="' + name + '" value="' + product_id + '" /><div class="wpbpc-select2-results"><ul></ul><a href="#">&times;</a></div>' );

			this.select2                = this.select2_search_field.closest( '.wpbpc-select2' );
			this.product_id_field       = this.select2.find( 'input[type="hidden"]' );
			this.select2_search_results = this.select2.find( '.wpbpc-select2-results' );
			this.select2_close_btn      = this.select2_search_results.find( 'a' );

			this.select2_close_btn.on( 'click', function ( e ) {
				e.preventDefault();
				self.select2_close();
			} );

			this.select2_search_field.on( 'keyup', _.debounce( function () {
				self.select2_search();
			}, 1000 ) );

			this.select2_search_results.on( 'click', 'li', function () {
				self.select2_select( jQuery( this ) );
			} );

			if ( product_id > 0 ) {
				this.select2_get_product( product_id );
			}
		};
	};

	jQuery( document ).ready( function () {
		new product_countdown().init();
	} );

})();



